pub fn set_hash_kind_for_test(kind: HashKind) -> HashKindGuardExpand description
Sets the hash kind for the current thread and returns a guard to reset it later.
pub fn set_hash_kind_for_test(kind: HashKind) -> HashKindGuardSets the hash kind for the current thread and returns a guard to reset it later.