pub struct Blob {
pub id: ObjectHash,
pub data: Vec<u8>,
}Expand description
The Blob Object
Fields
id: ObjectHashdata: Vec<u8>Implementations
Sourceimpl Blob
impl Blob
Sourcepub fn from_content(content: &str) -> Self
pub fn from_content(content: &str) -> Self
Create a new Blob object from the given content string.
- This is a convenience method for creating a Blob from a string.
- It converts the string to bytes and then calls
from_content_bytes.
Sourcepub fn from_content_bytes(content: Vec<u8>) -> Self
pub fn from_content_bytes(content: Vec<u8>) -> Self
Create a new Blob object from the given content bytes.
- some file content can’t be represented as a string (UTF-8), so we need to use bytes.