Commit

Struct Commit 

pub struct Commit {
    pub id: ObjectHash,
    pub tree_id: ObjectHash,
    pub parent_commit_ids: Vec<ObjectHash>,
    pub author: Signature,
    pub committer: Signature,
    pub message: String,
}
The Commit struct is used to represent a commit object.

  • The tree object SHA-1/SHA-256 hashpoints to the top level tree for this commit, which reflects the complete state of the repository at the time of the commit. The tree object in turn points to blobs and subtrees which represent the files in the repository.
  • The parent commit SHAs allow Git to construct a linked list of commits and build the full commit history. By chaining together commits in this fashion, Git is able to represent the entire history of a repository with a single commit object at its root.
  • The author and committer fields contain the name, email address, timestamp and timezone.
  • The message field contains the commit message, which maybe include signed or DCO.

Fields

id: ObjectHashtree_id: ObjectHashparent_commit_ids: Vec<ObjectHash>author: Signaturecommitter: Signaturemessage: String

Implementations

Source

impl Commit

pub fn new( author: Signature, committer: Signature, tree_id: ObjectHash, parent_commit_ids: Vec<ObjectHash>, message: &str, ) -> Commit

pub fn from_tree_id( tree_id: ObjectHash, parent_commit_ids: Vec<ObjectHash>, message: &str, ) -> Commit

Creates a new commit object from a tree ID and a list of parent commit IDs. This function generates the author and committer signatures using the current time and a fixed email address. It also sets the commit message to the provided string.

Arguments
  • tree_id: The SHA1/ SHA-256 hash of the tree object that this commit points to.
  • parent_commit_ids: A vector of SHA1/ SHA-256 hashes of the parent commits.
  • message: A string containing the commit message.
Returns

A new Commit object with the specified tree ID, parent commit IDs, and commit message. The author and committer signatures are generated using the current time and a fixed email address.

pub fn format_message(&self) -> String

Formats the commit message by extracting the first meaningful line.

If the message contains a PGP signature, it returns the first non-empty line after the signature block. Otherwise, it returns the first non-empty line in the message. If no such line exists, it returns the original message.