pub struct Plan { /* private fields */ }Expand description
Immutable planning revision for one Intent.
A Plan may form a DAG through parents, allowing Libra to model
linear replanning as well as multi-branch plan merges without losing
history.
Implementations
Sourceimpl Plan
impl Plan
Sourcepub fn new(created_by: ActorRef, intent: Uuid) -> Result<Self, String>
pub fn new(created_by: ActorRef, intent: Uuid) -> Result<Self, String>
Create a new root plan revision for the given intent.
Sourcepub fn new_revision(&self, created_by: ActorRef) -> Result<Self, String>
pub fn new_revision(&self, created_by: ActorRef) -> Result<Self, String>
Create a new child plan revision from this plan as the only parent.
Sourcepub fn new_revision_from(
created_by: ActorRef,
parent: &Self,
) -> Result<Self, String>
pub fn new_revision_from( created_by: ActorRef, parent: &Self, ) -> Result<Self, String>
Create a new plan revision from a single explicit parent.
Sourcepub fn new_revision_chain(
created_by: ActorRef,
parents: &[&Self],
) -> Result<Self, String>
pub fn new_revision_chain( created_by: ActorRef, parents: &[&Self], ) -> Result<Self, String>
Create a new plan revision from multiple parents.
All parents must belong to the same intent.
Sourcepub fn add_parent(&mut self, parent_id: Uuid)
pub fn add_parent(&mut self, parent_id: Uuid)
Add one parent link if it is not already present and is not self.
Sourcepub fn set_parents(&mut self, parents: Vec<Uuid>)
pub fn set_parents(&mut self, parents: Vec<Uuid>)
Replace the parent set for this in-memory plan revision.
Sourcepub fn context_frames(&self) -> &[Uuid]
pub fn context_frames(&self) -> &[Uuid]
Return the planning-time context frame ids frozen into this plan.
Sourcepub fn set_context_frames(&mut self, context_frames: Vec<Uuid>)
pub fn set_context_frames(&mut self, context_frames: Vec<Uuid>)
Replace the planning-time context frame set for this in-memory plan revision.