pub struct RunUsage { /* private fields */ }Expand description
Immutable token / cost summary for one Run.
Implementations
Sourceimpl RunUsage
impl RunUsage
Sourcepub fn new(
created_by: ActorRef,
run_id: Uuid,
input_tokens: u64,
output_tokens: u64,
cost_usd: Option<f64>,
) -> Result<Self, String>
pub fn new( created_by: ActorRef, run_id: Uuid, input_tokens: u64, output_tokens: u64, cost_usd: Option<f64>, ) -> Result<Self, String>
Create a new immutable usage summary for one run.
Sourcepub fn input_tokens(&self) -> u64
pub fn input_tokens(&self) -> u64
Return the input token count.
Sourcepub fn output_tokens(&self) -> u64
pub fn output_tokens(&self) -> u64
Return the output token count.
Sourcepub fn total_tokens(&self) -> u64
pub fn total_tokens(&self) -> u64
Return the total token count.
Sourcepub fn is_consistent(&self) -> bool
pub fn is_consistent(&self) -> bool
Validate that the stored total matches input plus output.