pub struct Task { /* private fields */ }Expand description
Stable work definition used by the scheduler and execution layer.
Task answers “what work should be done?” rather than “what is the
current runtime status?”. Current status is reconstructed from event
history in Libra.
Implementations
Sourceimpl Task
impl Task
Sourcepub fn new(
created_by: ActorRef,
title: impl Into<String>,
goal: Option<GoalType>,
) -> Result<Self, String>
pub fn new( created_by: ActorRef, title: impl Into<String>, goal: Option<GoalType>, ) -> Result<Self, String>
Create a new task definition with the given title and optional goal type.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
Return the longer-form task description, if present.
Sourcepub fn constraints(&self) -> &[String]
pub fn constraints(&self) -> &[String]
Return the explicit task constraints.
Sourcepub fn acceptance_criteria(&self) -> &[String]
pub fn acceptance_criteria(&self) -> &[String]
Return the acceptance criteria for task completion.
Sourcepub fn parent(&self) -> Option<Uuid>
pub fn parent(&self) -> Option<Uuid>
Return the parent task id, if this task was derived from another task.
Sourcepub fn origin_step_id(&self) -> Option<Uuid>
pub fn origin_step_id(&self) -> Option<Uuid>
Return the stable plan-step id that originally spawned this task, if present.
Sourcepub fn dependencies(&self) -> &[Uuid]
pub fn dependencies(&self) -> &[Uuid]
Return the task dependency list.
Sourcepub fn set_description(&mut self, description: Option<String>)
pub fn set_description(&mut self, description: Option<String>)
Set or clear the long-form task description.
Sourcepub fn add_constraint(&mut self, constraint: impl Into<String>)
pub fn add_constraint(&mut self, constraint: impl Into<String>)
Append one execution constraint to this task definition.
Sourcepub fn add_acceptance_criterion(&mut self, criterion: impl Into<String>)
pub fn add_acceptance_criterion(&mut self, criterion: impl Into<String>)
Append one acceptance criterion to this task definition.
Sourcepub fn set_requester(&mut self, requester: Option<ActorRef>)
pub fn set_requester(&mut self, requester: Option<ActorRef>)
Set or clear the requesting actor for this task.
Sourcepub fn set_parent(&mut self, parent: Option<Uuid>)
pub fn set_parent(&mut self, parent: Option<Uuid>)
Set or clear the parent task link.
Sourcepub fn set_intent(&mut self, intent: Option<Uuid>)
pub fn set_intent(&mut self, intent: Option<Uuid>)
Set or clear the originating intent link.
Sourcepub fn set_origin_step_id(&mut self, origin_step_id: Option<Uuid>)
pub fn set_origin_step_id(&mut self, origin_step_id: Option<Uuid>)
Set or clear the originating stable plan-step link.
Sourcepub fn add_dependency(&mut self, task_id: Uuid)
pub fn add_dependency(&mut self, task_id: Uuid)
Append one prerequisite task id to the dependency list.