Object type enumeration and AI Object Header Definition.
This module defines the common metadata header shared by all AI process objects and the object type enumeration used across pack/object modules.
Structs
- Actor
Ref - Actor reference (who created/triggered).
- Artifact
Ref - Artifact reference (external content).
- Header
- Header shared by all AI Process Objects.
Enums
- Actor
Kind - Actor kind enum
- Object
Type - In Git, each object type is assigned a unique integer value, which is used to identify the type of the object in Git repositories.
- Visibility
- Visibility of an AI process object.
Constants
- CURRENT_
HEADER_ VERSION - Current header format version for newly created objects.