pub struct ArtifactRef { /* private fields */ }Expand description
Artifact reference (external content).
Implementations
Sourceimpl ArtifactRef
impl ArtifactRef
pub fn new( store: impl Into<String>, key: impl Into<String>, ) -> Result<Self, String>
pub fn store(&self) -> &str
pub fn key(&self) -> &str
pub fn content_type(&self) -> Option<&str>
pub fn size_bytes(&self) -> Option<u64>
pub fn hash(&self) -> Option<&IntegrityHash>
pub fn expires_at(&self) -> Option<DateTime<Utc>>
Sourcepub fn compute_hash(content: &[u8]) -> IntegrityHash
pub fn compute_hash(content: &[u8]) -> IntegrityHash
Calculate hash for the given content bytes.
Sourcepub fn with_hash(self, hash: IntegrityHash) -> Self
pub fn with_hash(self, hash: IntegrityHash) -> Self
Set the hash directly.
Sourcepub fn with_hash_hex(self, hash: impl AsRef<str>) -> Result<Self, String>
pub fn with_hash_hex(self, hash: impl AsRef<str>) -> Result<Self, String>
Set the hash from a hex string.
pub fn set_content_type(&mut self, content_type: Option<String>)
pub fn set_size_bytes(&mut self, size_bytes: Option<u64>)
pub fn set_expires_at(&mut self, expires_at: Option<DateTime<Utc>>)
Sourcepub fn verify_integrity(&self, content: &[u8]) -> Result<bool, String>
pub fn verify_integrity(&self, content: &[u8]) -> Result<bool, String>
Verify if the provided content matches the stored checksum
Sourcepub fn content_eq(&self, other: &Self) -> Option<bool>
pub fn content_eq(&self, other: &Self) -> Option<bool>
Check if two artifacts have the same content based on checksum
Sourcepub fn is_expired(&self) -> bool
pub fn is_expired(&self) -> bool
Check if the artifact has expired