pub struct CacheObject {
pub offset: usize,
pub crc32: u32,
pub data_decompressed: Vec<u8>,
pub mem_recorder: Option<Arc<AtomicUsize>>,
pub is_delta_in_pack: bool,
/* private fields */
}Expand description
Represents a cached object in memory, which may be a delta or a base object.
Fields
offset: usizecrc32: u32data_decompressed: Vec<u8>mem_recorder: Option<Arc<AtomicUsize>>is_delta_in_pack: boolImplementations
Sourceimpl CacheObject
impl CacheObject
Sourcepub fn new_for_undeltified(
obj_type: ObjectType,
data: Vec<u8>,
offset: usize,
crc32: u32,
) -> Self
pub fn new_for_undeltified( obj_type: ObjectType, data: Vec<u8>, offset: usize, crc32: u32, ) -> Self
Create a new CacheObject which is neither ObjectType::OffsetDelta nor ObjectType::HashDelta.
Sourcepub fn object_type(&self) -> ObjectType
pub fn object_type(&self) -> ObjectType
Get the ObjectType of the object.
Sourcepub fn base_object_hash(&self) -> Option<ObjectHash>
pub fn base_object_hash(&self) -> Option<ObjectHash>
Get the ObjectHash hash of the object.
If the object is a delta object, return None.
Sourcepub fn offset_delta(&self) -> Option<usize>
pub fn offset_delta(&self) -> Option<usize>
Get the offset delta of the object.
If the object is not an offset delta, return None.
Sourcepub fn hash_delta(&self) -> Option<ObjectHash>
pub fn hash_delta(&self) -> Option<ObjectHash>
Get the hash delta of the object.
If the object is not a hash delta, return None.
Sourcepub fn to_entry_metadata(&self) -> MetaAttached<Entry, EntryMeta>
pub fn to_entry_metadata(&self) -> MetaAttached<Entry, EntryMeta>
transform the CacheObject to MetaAttached<Entry, EntryMeta>