Simple channel-backed BufRead adapter so pack decoding can consume data streamed from async
tasks or background threads.
Simple channel-backed BufRead adapter so pack decoding can consume data streamed from async
tasks or background threads.