Module entry

Module entry 

Lightweight representation of a decoded Git object coming out of a pack stream, with helpers to convert to/from strongly typed objects.

Structs

Entry
Git object data from pack file