Module waitlist

Module waitlist 

Temporary storage for delta objects while their base object is still decoding, keyed by both pack offset and object hash.

Structs

Waitlist
Waitlist for Delta objects while the Base object is not ready. Easier and faster than Channels.