pub struct Waitlist {
pub map_offset: DashMap<usize, Vec<CacheObject>>,
pub map_ref: DashMap<ObjectHash, Vec<CacheObject>>,
}Expand description
Waitlist for Delta objects while the Base object is not ready. Easier and faster than Channels.
Fields
map_offset: DashMap<usize, Vec<CacheObject>>map_ref: DashMap<ObjectHash, Vec<CacheObject>>Implementations
Sourceimpl Waitlist
impl Waitlist
Sourcepub fn insert_offset(&self, offset: usize, obj: CacheObject)
pub fn insert_offset(&self, offset: usize, obj: CacheObject)
Insert an object into the waitlist by its pack offset or object hash.
Sourcepub fn insert_ref(&self, hash: ObjectHash, obj: CacheObject)
pub fn insert_ref(&self, hash: ObjectHash, obj: CacheObject)
Insert an object into the waitlist by its object hash.
Sourcepub fn take(&self, offset: usize, hash: ObjectHash) -> Vec<CacheObject>
pub fn take(&self, offset: usize, hash: ObjectHash) -> Vec<CacheObject>
Take objects out (get & remove)
Return Vec::new() if None