pub struct Wrapper<R> { /* private fields */ }Expand description
Wrapper is a wrapper around a reader that also computes the SHA1/ SHA256 hash of the data read.
It is designed to work with any reader that implements BufRead.
Fields:
inner: The inner reader.hash: The optional hash state.Nonemeans only bytes read are counted.bytes_read: The number of bytes consumed from the wrapped reader.
Implementations
Sourceimpl<R> Wrapper<R>where
R: BufRead,
impl<R> Wrapper<R>where
R: BufRead,
Sourcepub fn new_without_hash(inner: R) -> Self
pub fn new_without_hash(inner: R) -> Self
Constructs a wrapper that only tracks bytes read, skipping the running hash.
Sourcepub fn bytes_read(&self) -> usize
pub fn bytes_read(&self) -> usize
Returns the number of bytes read so far.
Sourcepub fn final_hash(&self) -> ObjectHash
pub fn final_hash(&self) -> ObjectHash
Returns the final SHA1/ SHA256 hash of the data read so far.
This is a clone of the internal hash state finalized into a SHA1/ SHA256 hash.