Module zlib
git_
internal
0.7.3
Module zlib
Module Items
Modules
In git_
internal::
internal
git_internal
::
internal
Module
zlib
Thin wrappers around zlib streams tailored for Git objects, exposing buffered decompressors.
Modules

stream
Streaming primitives used to inflate Git objects from pack files.