macro_rules! time_it {
($msg:expr, $block:block) => { ... };
}Expand description
Count the time taken to execute a block of code.
macro_rules! time_it {
($msg:expr, $block:block) => { ... };
}Count the time taken to execute a block of code.