Module smart

Module smart 

Implementation of the Git smart protocol state machine, handling capability negotiation, pkt exchanges, authentication delegation, and bridging repository storage to transport streams.

Structs

SmartProtocol
Smart Git Protocol implementation