pub struct DiffItem {
pub path: String,
pub data: String,
}Expand description
This struct is returned by diff operations and contains:
path: The file path being diffed.data: The complete unified diff output string for that file, or a large-file marker if the file is too large to diff.
Fields
path: StringThe file path being diffed.
data: StringThe complete unified diff output string for that file, or a large-file marker if the file is too large to diff.