Module context

Module context 

AI Context Snapshot Definition

A ContextSnapshot represents the state of the codebase and external resources that an agent uses to perform its task.

Selection Strategy

  • Explicit: User manually selected files.
  • Heuristic: Agent automatically selected files based on relevance.

Integrity

Each item in the snapshot has a content hash (IntegrityHash). This ensures that if the file changes on disk, we know the snapshot is stale or refers to an older version.

Structs

ContextItem
Context item describing a single input.
ContextSnapshot
Context snapshot describing selected inputs. Captures the selection strategy and content identifiers used by a run.

Enums

ContextItemKind
Context item kind.
SelectionStrategy
Selection strategy for context snapshots.