Module patchset

Module patchset 

AI PatchSet Definition

A PatchSet represents a proposed set of code changes (diffs) generated by an agent.

Generations

PatchSets are often created in generations (iterations). If a PatchSet fails validation or code review, the agent may generate a new PatchSet (generation N+1) for the same Run.

Content

The actual diff content is stored as an ArtifactRef (e.g., pointing to a file in object storage), while TouchedFile provides a lightweight summary for UI/indexing.

Structs

PatchSet
PatchSet object containing a candidate diff. Each generation represents a new candidate diff for the same run.
TouchedFile
Touched file summary in a patchset.

Enums

ApplyStatus
Patch application status.
ChangeType
Type of change for a file.
DiffFormat
Diff format for patch content.