SignatureType

Enum SignatureType 

pub enum SignatureType {
    Author,
    Committer,
    Tagger,
}
In addition to the author signature, Git also includes a “committer” signature, which indicates who committed the changes to the repository. The committer signature is similar in structure to the author signature, but includes the name, email address, and timestamp of the committer instead. This can be useful in situations where multiple people are working on a project and changes are being reviewed and merged by someone other than the original author.

In the following example, it’s has the only one who authored and committed.

author Eli Ma <eli@patch.sh> 1678102132 +0800
committer Quanyi Ma <eli@patch.sh> 1678102132 +0800

So, we design a SignatureType enum to indicate the signature type.

Variants



Author



Committer



Tagger

Implementations

Source

impl SignatureType

pub fn from_data(data: Vec<u8>) -> Result<Self, GitError>

The from_data method is used to convert a Vec<u8> to a SignatureType enum.

pub fn to_bytes(&self) -> Vec<u8>

The to_bytes method is used to convert a SignatureType enum to a Vec<u8>.