pub struct Tree {
pub id: ObjectHash,
pub tree_items: Vec<TreeItem>,
}Expand description
A tree object is a Git object that represents a directory. It contains a list of entries, one for each file or directory in the tree.
Fields
id: ObjectHashtree_items: Vec<TreeItem>Implementations