Tree

Struct Tree 

pub struct Tree {
    pub id: ObjectHash,
    pub tree_items: Vec<TreeItem>,
}
A tree object is a Git object that represents a directory. It contains a list of entries, one for each file or directory in the tree.

Fields

id: ObjectHashtree_items: Vec<TreeItem>

Implementations

Source

impl Tree

pub fn from_tree_items(tree_items: Vec<TreeItem>) -> Result<Self, GitError>

pub fn rehash(&mut self)

After the subdirectory is changed, the hash value of the tree is recalculated.