pub struct TreeItem {
pub mode: TreeItemMode,
pub id: ObjectHash,
pub name: String,
}Expand description
A tree object contains a list of entries, one for each file or directory in the tree. Each entry in the file represents an entry in the tree, and each entry has the following format:
<mode> <name>\0<binary object ID><mode>is the mode of the object, represented as a six-digit octal number. The first digit represents the object type (tree, blob, etc.), and the remaining digits represent the file mode or permissions.<name>is the name of the object.\0is a null byte separator.<binary object ID>is the ID of the object that represents the contents of the file or directory, represented as a binary SHA-1 hash.
Example
100644 hello-world\0<blob object ID>
040000 data\0<tree object ID>Fields
mode: TreeItemModeid: ObjectHashname: StringImplementations
Sourceimpl TreeItem
impl TreeItem
Sourcepub fn new(mode: TreeItemMode, id: ObjectHash, name: String) -> Self
pub fn new(mode: TreeItemMode, id: ObjectHash, name: String) -> Self
Creates a new TreeItem with the given mode, object ID, and name.
Sourcepub fn from_bytes(bytes: &[u8]) -> Result<Self, GitError>
pub fn from_bytes(bytes: &[u8]) -> Result<Self, GitError>
Create a new TreeItem from a byte vector, split into a mode, id and name, the TreeItem format is:
<mode> <name>\0<binary object ID>Sourcepub fn to_data(&self) -> Vec<u8> ⓘ
pub fn to_data(&self) -> Vec<u8> ⓘ
Convert a TreeItem to a byte vector
use std::str::FromStr;
use git_internal::internal::object::tree::{TreeItem, TreeItemMode};
use git_internal::hash::ObjectHash;
let tree_item = TreeItem::new(
TreeItemMode::Blob,
ObjectHash::from_str("8ab686eafeb1f44702738c8b0f24f2567c36da6d").unwrap(),
"hello-world".to_string(),
);