Module types

Module types 

Object type enumeration and AI Object Header Definition.

This module defines the common metadata header shared by all AI process objects and the object type enumeration used across pack/object modules.

Structs

ActorRef
Actor reference (who created/triggered).
ArtifactRef
Artifact reference (external content).
Header
Header shared by all AI Process Objects.

Enums

ActorKind
Actor kind enum
ObjectType
In Git, each object type is assigned a unique integer value, which is used to identify the type of the object in Git repositories.
Visibility
Visibility of an AI process object.