pub struct Header { /* private fields */ }Expand description
Implementations
Sourceimpl Header
impl Header
Sourcepub fn new(
object_type: ObjectType,
repo_id: Uuid,
created_by: ActorRef,
) -> Result<Self, String>
pub fn new( object_type: ObjectType, repo_id: Uuid, created_by: ActorRef, ) -> Result<Self, String>
Create a new Header with default values.
Arguments
object_type- The specific type of the AI object.repo_id- The UUID of the repository this object belongs to.created_by- The actor (human/agent) creating this object.
pub fn object_id(&self) -> Uuid
pub fn object_type(&self) -> &ObjectType
pub fn schema_version(&self) -> u32
pub fn repo_id(&self) -> Uuid
pub fn created_at(&self) -> DateTime<Utc>
pub fn created_by(&self) -> &ActorRef
pub fn visibility(&self) -> &Visibility
pub fn external_ids(&self) -> &HashMap<String, String>
pub fn external_ids_mut(&mut self) -> &mut HashMap<String, String>
pub fn set_object_id(&mut self, object_id: Uuid)
pub fn set_object_type(&mut self, object_type: ObjectType) -> Result<(), String>
pub fn set_schema_version(&mut self, schema_version: u32) -> Result<(), String>
pub fn set_created_at(&mut self, created_at: DateTime<Utc>)
pub fn set_visibility(&mut self, visibility: Visibility)
Sourcepub fn checksum(&self) -> Option<&IntegrityHash>
pub fn checksum(&self) -> Option<&IntegrityHash>
Accessor for checksum
Sourcepub fn seal<T: Serialize>(&mut self, object: &T) -> Result<(), Error>
pub fn seal<T: Serialize>(&mut self, object: &T) -> Result<(), Error>
Seal the header by calculating and setting the checksum of the provided object. The checksum field is temporarily cleared to keep sealing idempotent.
This is typically called just before storing the object to ensure checksum matches content.