pub struct ArcWrapper<T: ArcWrapperBounds> {
pub data: Arc<T>,
pub store_path: Option<PathBuf>,
/* private fields */
}Expand description
Implementing encapsulation of Arc to enable third-party Trait HeapSize implementation for the Arc type Because of use Arc in LruCache, the LruCache is not clear whether a pointer will drop the referenced content when it is ejected from the cache, the actual memory usage is not accurate
Fields
data: Arc<T>store_path: Option<PathBuf>Implementations
Sourceimpl<T: ArcWrapperBounds> ArcWrapper<T>
impl<T: ArcWrapperBounds> ArcWrapper<T>
Sourcepub fn new(
data: Arc<T>,
share_flag: Arc<AtomicBool>,
pool: Option<Arc<ThreadPool>>,
) -> Self
pub fn new( data: Arc<T>, share_flag: Arc<AtomicBool>, pool: Option<Arc<ThreadPool>>, ) -> Self
Create a new ArcWrapper
pub fn set_store_path(&mut self, path: PathBuf)