CacheObject

Struct CacheObject 

pub struct CacheObject {
    pub offset: usize,
    pub data_decompressed: Vec<u8>,
    pub mem_recorder: Option<Arc<AtomicUsize>>,
    /* private fields */
}

Fields

offset: usizedata_decompressed: Vec<u8>mem_recorder: Option<Arc<AtomicUsize>>

Implementations

Source

impl CacheObject

pub fn new_for_undeltified( obj_type: ObjectType, data: Vec<u8>, offset: usize, ) -> Self

Create a new CacheObject which is neither ObjectType::OffsetDelta nor ObjectType::HashDelta.

pub fn object_type(&self) -> ObjectType

Get the ObjectType of the object.

pub fn base_object_hash(&self) -> Option<SHA1>

Get the SHA1 hash of the object.

If the object is a delta object, return None.

pub fn offset_delta(&self) -> Option<usize>

Get the offset delta of the object.

If the object is not an offset delta, return None.

pub fn hash_delta(&self) -> Option<SHA1>

Get the hash delta of the object.

If the object is not a hash delta, return None.

pub fn to_entry(&self) -> Entry

transform the CacheObject to Entry