PackEncoder

Struct PackEncoder 

pub struct PackEncoder { /* private fields */ }
A encoder for generating pack files with delta objects.

Implementations

Source

impl PackEncoder

pub fn new( object_number: usize, window_size: usize, sender: Sender<Vec<u8>>, ) -> Self

pub fn new_with_idx( object_number: usize, window_size: usize, pack_sender: Sender<Vec<u8>>, idx_sender: Sender<Vec<u8>>, ) -> Self

pub fn drop_sender(&mut self)

pub async fn send_data(&mut self, data: Vec<u8>)

pub fn get_hash(&self) -> Option<ObjectHash>

Get the hash of the pack file. if the pack file is not finished, return None

pub async fn encode( &mut self, entry_rx: Receiver<MetaAttached<Entry, EntryMeta>>, ) -> Result<(), GitError>

Encodes entries into a pack file with delta objects and outputs them through the specified writer.

Arguments
  • rx - A receiver channel (mpsc::Receiver<Entry>) from which entries to be encoded are received.
Returns

Returns Ok(()) if encoding is successful, or a GitError in case of failure.

  • Returns a GitError if there is a failure during the encoding process.
  • Returns PackEncodeError if an encoding operation is already in progress.
pub async fn encode_with_zstdelta( &mut self, entry_rx: Receiver<MetaAttached<Entry, EntryMeta>>, ) -> Result<(), GitError>

Encode with zstdelta

pub async fn parallel_encode( &mut self, entry_rx: Receiver<MetaAttached<Entry, EntryMeta>>, ) -> Result<(), GitError>

Parallel encode with rayon, only works when window_size == 0 (no delta)

pub async fn encode_async( self, rx: Receiver<MetaAttached<Entry, EntryMeta>>, ) -> Result<JoinHandle<()>, GitError>

async version of encode, result data will be returned by JoinHandle. It will consume PackEncoder, so you can’t use it after calling this function. when window_size = 0, it executes parallel_encode which retains stream transmission when window_size = 0,it executes encode which uses magic sort and delta. It seems that all other modules rely on this api

pub async fn encode_async_with_zstdelta( self, rx: Receiver<MetaAttached<Entry, EntryMeta>>, ) -> Result<JoinHandle<()>, GitError>

async version of encode_with_zstdelta, result data will be returned by JoinHandle.

pub async fn encode_idx_file(&mut self) -> Result<(), GitError>

Generate idx file after pack file has been generated