Wrapper

Struct Wrapper 

pub struct Wrapper<R> { /* private fields */ }
Wrapper is a wrapper around a reader that also computes the SHA1/ SHA256 hash of the data read.

It is designed to work with any reader that implements BufRead.

Fields:

  • inner: The inner reader.
  • hash: The hash state.
  • count_hash: A flag to indicate whether to compute the hash while reading.

Implementations

Source

impl<R> Wrapper<R>
where R: BufRead,

pub fn new(inner: R) -> Self

Constructs a new Wrapper with the given reader and a flag to enable or disable hashing.

Parameters
  • inner: The reader to wrap.
  • count_hash: If true, the hash is computed while reading; otherwise, it is not.
pub fn bytes_read(&self) -> usize

Returns the number of bytes read so far.

pub fn final_hash(&self) -> ObjectHash

Returns the final SHA1/ SHA256 hash of the data read so far.

This is a clone of the internal hash state finalized into a SHA1/ SHA256 hash.