pub struct Wrapper<R> { /* private fields */ }Expand description
Wrapper is a wrapper around a reader that also computes the SHA1 hash of the data read.
It is designed to work with any reader that implements BufRead.
Fields:
inner: The inner reader.hash: The SHA1 hash state.count_hash: A flag to indicate whether to compute the hash while reading.
Implementations