Module http

Module http 

Structs

HttpGitHandler
HTTP Git protocol handler
InfoRefsParams
Parameters for git info-refs request

Functions

extract_repo_path
Extract repository path from HTTP request path
get_advertisement_content_type
Get content type for Git HTTP info/refs advertisement
get_content_type
HTTP-specific utility functions Get content type for Git HTTP responses
get_service_from_query
Get Git service from query parameters
is_git_request
Check if request is a Git smart protocol request