Module utils

Module utils 

Functions

add_pkt_line_string
Add a packet line string to the buffer with proper length prefix
build_smart_reply
read_pkt_line
Read a packet line from the given bytes buffer
read_until_white_space
Read until whitespace and return the extracted string
search_subsequence
Search for a subsequence in a byte slice