Functions
- add_
pkt_ line_ string - Add a packet line string to the buffer with proper length prefix
- build_
smart_ reply - read_
pkt_ line - Read a packet line from the given bytes buffer
- read_
until_ white_ space - Read until whitespace and return the extracted string
- search_
subsequence - Search for a subsequence in a byte slice